espnsportsapi

package module
v0.0.0-...-ed4cb9a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 8, 2023 License: GPL-3.0 Imports: 4 Imported by: 0

README

espnsportsapi

golang implementation of my work in progress python api wrapper of the ESPN hidden api for sports (this is not for their fantasy football api this is for real sports)

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetScoreboard

func GetScoreboard(sport string, league string, date string) string

Types

This section is empty.

Jump to